#!/bin/sh
#
# Copyright (c) 2001-2002 by Leni Mayo
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License, version 2, as
#	published by the Free Software Foundation.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
# srcdir may get passed in by autoconf
#
if [ "$srcdir" != "" ]; then
	srcdir=$srcdir"/"
else
	srcdir="/"
fi

srcdir="`pwd`/$srcdir"

# Test the locally built versions, in preference to the installed ones.
# Also, there might not be anything installed as yet (eg. during "make check")
export PATH=../src:../scripts:$PATH

# Source some functions
. $srcdir"testfunctions"

echo -n "Test serelhistory --query prior-history ... "
directory=$srcdir"6"

tmpfile=`mktemp -q /tmp/XXXXXX`
tmpconfigfile=`mktemp -q /tmp/XXXXXX`
tmpfiles="$tmpfile $tmpconfigfile"

if [ ! -w $tmpfile -o ! -w $tmpconfigfile ]; then
	echo Unable to create temporary file.
	failure $LINENO
fi

# build the serel config file on the fly.
# We only go though this gynastic because relative pathnames
# are meaningless under autoconf's "make distcheck"
#
cat <<- EOF > $tmpconfigfile
	# Test #6
	#
	rdfpath = $directory/conf/default.rdf
	dbdirectory = $directory/data/
	mangledollar = strip
	EOF

startServer -c $tmpconfigfile
[ $? != "0" ] && failure $LINENO

# Make sure that the data directory is empty to begin with
rm $directory/data/*.db > /dev/null 2>&1

# always stop the server and remove the tmp files, no matter what
trap "serelc --control stop > /dev/null 2>&1; rm $tmpfiles > /dev/null 2>&1; rm $directory/data/*.db" EXIT

SEREL_PAIRS=
for i in "$directory"/*; do
	if [ ! -d $i ]; then
		service=`basename $i`
		SEREL_PAIRS="$SEREL_PAIRS $service $i" 
	fi
done

serelhistory --populate <<- END
	--pairs
	$SEREL_PAIRS
	END
[ $? != "0" ] && failure $LINENO

serelhistory --query verify | grep "success" 2>&1 > /dev/null
[ $? != "0" ] && failure $LINENO

# We don't expect the prior history to have been used - there wasn't any!
#
serelhistory --query prior-history | grep "success" 2>&1 > /dev/null
[ $? == "0" ] && failure $LINENO

for i in "$directory"/*; do
	[ ! -d $i ] && serel-wrap $i start &
done

wait

testStatus $directory "eStateIn"

# The expected dependency graph is:
#
#                       /-->  apmd   ---\
#  start -->  syslog ---                 --> local
#                       \--> anacron ---/
#

serelhistory --query prior-history | grep "success" 2>&1 > /dev/null
[ $? == "0" ] && failure $LINENO

serelc --control stop > /dev/null 2>&1

startServer -c $tmpconfigfile
[ $? != "0" ] && failure $LINENO

serelhistory --populate <<- END
	--pairs
	$SEREL_PAIRS
	END
[ $? != "0" ] && failure $LINENO

serelhistory --query verify | grep "success" 2>&1 > /dev/null
[ $? != "0" ] && failure $LINENO

# Now we expect the prior history to have been used...
#
serelhistory --query prior-history | grep -v "success" 2>&1 > /dev/null
[ $? == "0" ] && failure $LINENO

success
