#!/bin/sh
#
# Copyright (c) 2001-2002 by Leni Mayo
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License, version 2, as
#	published by the Free Software Foundation.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
# srcdir may get passed in by autoconf
#
if [ "$srcdir" != "" ]; then
	srcdir=$srcdir"/"
else
	srcdir="/"
fi

srcdir="`pwd`/$srcdir"

# Test the locally built versions, in preference to the installed ones.
# Also, there might not be anything installed as yet (eg. during "make check")
export PATH=../src:../scripts:$PATH

# Source some functions
. $srcdir"testfunctions"

echo -n "Test regression - bugs fixed once should remain fixed ... "

tmpfile=`mktemp -q /tmp/XXXXXX`
tmpconfigfile=`mktemp -q /tmp/XXXXXX`
tmpfileFirst=`mktemp -q /tmp/XXXXXX`
tmpfiles="$tmpfile $tmpconfigfile $tmpfileFirst"

if [ ! -w $tmpfile -o ! -w $tmpconfigfile -o ! -w $tmpfileFirst ]; then
	echo Unable to create temporary file.
	failure $LINENO
fi

# always stop the server and remove the tmp files, no matter what
trap "serelc --control stop > /dev/null 2>&1; rm $tmpfiles > /dev/null 2>&1" EXIT


# build the serel config file on the fly.
# We only go though this gynastic because relative pathnames
# are meaningless under autoconf's "make distcheck"
#
cat <<- EOF > $tmpconfigfile
	# Test #7.1
	#
	rdfpath = $srcdir/../data/redhat-serel-default.rdf
	dbignore = yes
	mangledollar = strip
	EOF

startServer -c $tmpconfigfile
[ $? != "0" ] && failure $LINENO

# There can't be a history immediately after startup
#
serelhistory --query prior-history | grep -v "success" 2>&1 > /dev/null
[ $? == "1" ] && failure $LINENO

serelhistory --populate <<- END
	--started
	--pairs
	service boguspathname
	END
[ $? != "0" ] && failure $LINENO

# Make sure the daemon is still running
#
serelc --control stop
[ $? != "0" ] && failure $LINENO

# test that lsb2rdf doesn't barf in the presence of ignorable LSB comments
#
directory=$srcdir"7/1"
lsb2rdf $directory/afs > /dev/null 2>&1
[ $? != "0" ] && failure $LINENO

directory=$srcdir"7/2"
# test that bug #2002-08-09-01 remains fixed (redland 0.9.10) bug
#

cat <<- EOF > $tmpconfigfile
	# Test #7.2
	#
	rdfpath = $directory/conf/serel-local.rdf;$directory/conf/redhat-serel-default.rdf
	dbdirectory = $directory/data
	# dbignore = yes
	EOF

cat <<- EOF > $tmpfileFirst
	<?xml version="1.0" encoding="utf-8"?>
	<rdf:RDF
	  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	  xmlns:serel="http://www.fastboot.org/2002/03/serel-schema#" 
	>
	<rdf:Description about="file:/$directory/S10network" serel:parse="false" />
	</rdf:RDF>
	EOF

rm $directory/data/* > /dev/null 2>&1

startServer -c $tmpconfigfile
[ $? != "0" ] && failure $LINENO

# everything links to S95atd, except for:
# - S10network, which can't be a symbolic link because it gets ignored by the serel:parse property
# - S60afs, which contains some LSB comments
#
# symlinks="S02current S05kudzu S08ipchains S12syslog S17keytable S20random S55sshd S56rawdevices S56xinetd S60lpd S80postfix S85gpm S85httpd S90crond S90sue S90xfs S97rhnsd S98audit S99local"
symlinks="S02current S05kudzu S08ipchains S12syslog"

for i in $symlinks; do
	rm $directory/$i > /dev/null 2>& 1
done

for i in $symlinks; do
	if [ ! -e "$directory/$i" ]; then
		ln -s "$directory"/S95atd "$directory"/$i
	fi
done

SEREL_PAIRS=
for i in "$directory"/*; do
	if [ ! -d $i ]; then
		base=`basename $i`
		service=${base#S??}
		SEREL_PAIRS="$SEREL_PAIRS $service $i"
	fi
done

serelhistory --populate <<- END
	--pairs
	$SEREL_PAIRS
	END
[ $? != "0" ] && failure $LINENO

serelhistory --query verify | grep "success" 2>&1 > /dev/null
[ $? != "0" ] && failure $LINENO

for i in "$directory"/*; do
	[ ! -d $i ] && serel-wrap $i start &
done

wait

serelc --query graph > $tmpfile
[ $? != "0" ] && failure $LINENO

rm $directory/data/* > /dev/null 2>&1

success
